@@ -70,7 +70,6 @@ typedef struct _MetaOutputPrivate
 
   int backlight;
 
-  MetaPrivacyScreenState privacy_screen_state;
   gboolean is_privacy_screen_enabled;
 
   MetaOutputHdrMetadata hdr_metadata;
@@ -113,6 +112,8 @@ meta_output_info_unref (MetaOutputInfo *output_info)
       g_free (output_info->serial);
       g_free (output_info->edid_checksum_md5);
       g_clear_pointer (&output_info->edid_info, meta_edid_info_free);
+      for (int i = 0; i < output_info->n_modes; i++)
+        g_object_unref (output_info->modes[i]);
       g_free (output_info->modes);
       g_free (output_info->possible_crtcs);
       g_free (output_info->possible_clones);
@@ -478,7 +479,7 @@ meta_output_is_privacy_screen_enabled (MetaOutput *output)
 {
   MetaOutputPrivate *priv = meta_output_get_instance_private (output);
 
-  return priv->privacy_screen_state;
+  return priv->is_privacy_screen_enabled;
 }
 
 gboolean
@@ -489,7 +490,7 @@ meta_output_set_privacy_screen_enabled (MetaOutput  *output,
   MetaOutputPrivate *priv = meta_output_get_instance_private (output);
   MetaPrivacyScreenState state;
 
-  state = priv->privacy_screen_state;
+  state = meta_output_get_privacy_screen_state (output);
 
   if (state == META_PRIVACY_SCREEN_UNAVAILABLE)
     {
@@ -506,7 +507,7 @@ meta_output_set_privacy_screen_enabled (MetaOutput  *output,
       return FALSE;
     }
 
-  if (priv->is_privacy_screen_enabled == enabled)
+  if ((state == META_PRIVACY_SCREEN_ENABLED) == enabled)
     return TRUE;
 
   priv->is_privacy_screen_enabled = enabled;
